<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozhovor</translation>
    </message>
    <message>
        <source>Words fix</source>
        <translation>Oprava slov</translation>
    </message>
    <message>
        <source>Enable word fix</source>
        <translation>Povolit opravu slov</translation>
    </message>
    <message>
        <source>Spelling</source>
        <translation>Pravopis</translation>
    </message>
</context>
<context>
    <name>WordFixConfigurationUiHandler</name>
    <message>
        <source>A word to be replaced</source>
        <translation>Slovo, které se má nahradit</translation>
    </message>
    <message>
        <source>Value to replace with</source>
        <translation>Hodnota, která se má změnit</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Změnit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Word</source>
        <translation>Slovo</translation>
    </message>
    <message>
        <source>Replace with</source>
        <translation>Nahradit</translation>
    </message>
</context>
</TS>